aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/cc/module.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2019-09-18 15:57:52 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2019-09-18 15:57:52 +0200
commit8c30c59de2d304a416dfd4fcb821e0b227e5db96 (patch)
treef249eabbe955b38c5516e68f7577bbb4b5dbc705 /libbuild2/cc/module.cxx
parent04bfd3bf7a71197bdf5f697e323c70e98b857571 (diff)
Rename importable_headers variable to translatable_headers
This name aligns better with the post-Cologne importable/translatable semantics.
Diffstat (limited to 'libbuild2/cc/module.cxx')
-rw-r--r--libbuild2/cc/module.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/libbuild2/cc/module.cxx b/libbuild2/cc/module.cxx
index 3113b5c..64ae874 100644
--- a/libbuild2/cc/module.cxx
+++ b/libbuild2/cc/module.cxx
@@ -527,20 +527,20 @@ namespace build2
rs.assign (x_libs) += cast_null<strings> (
config::optional (rs, config_x_libs));
- // config.x.importable_header
+ // config.x.translatable_header
//
// It's still fuzzy whether specifying (or maybe tweaking) this list in
// the configuration will be a common thing to do so for now we use
// omitted. It's also probably too early to think whether we should have
// the cc.* version and what the semantics should be.
//
- if (x_importable_headers != nullptr)
+ if (x_translatable_headers != nullptr)
{
- lookup l (config::omitted (rs, *config_x_importable_headers).first);
+ lookup l (config::omitted (rs, *config_x_translatable_headers).first);
// @@ MODHDR: if(modules) ?
//
- rs.assign (x_importable_headers) += cast_null<strings> (l);
+ rs.assign (x_translatable_headers) += cast_null<strings> (l);
}
// Load cc.core.config.
@@ -567,14 +567,14 @@ namespace build2
if (!cast_false<bool> (rs["cc.core.loaded"]))
load_module (rs, rs, "cc.core", loc);
// Process, sort, and cache (in this->import_hdr) importable headers.
// Keep the cache NULL if unused or empty.
//
// @@ MODHDR TODO: support exclusions entries (e.g., -<stdio.h>)?
//
- if (modules && x_importable_headers != nullptr)
+ if (modules && x_translatable_headers != nullptr)
{
- strings* ih (cast_null<strings> (rs.assign (x_importable_headers)));
+ strings* ih (cast_null<strings> (rs.assign (x_translatable_headers)));
if (ih != nullptr && !ih->empty ())
{
@@ -631,7 +631,7 @@ namespace build2
}
sort (ih->begin (), ih->end ());
- import_hdr = ih;
+ xlate_hdr = ih;
}
}
@@ -567,14 +567,14 @@ namespace build2
if (!cast_false<bool> (rs["cc.core.loaded"]))
load_module (rs, rs, "cc.core", loc);
- // Process, sort, and cache (in this->import_hdr) importable headers.
+ // Process, sort, and cache (in this->xlate_hdr) translatable headers.
// Keep the cache NULL if unused or empty.
//